/*
 * File:   O-BUZZER
 * Author: Bart Huyskens - www.e2cre8.be  04/2016
 * HARDWARE: BRAINBOX FUN - PIC18F445 + Bootloader running at 48Mhz
 * 
 * This program alternatingly makes the 4 power output pins high
 * with 1 sec delays
 * 4 pins connected to the L293D H Bridge - make sure that the jumpers are set
 * C2 - E1 - E0 - C1
 */
// PIC18F4455 Configuration Bit Settings - 
// all config settings are made in the bootloader

#include <xc.h>   // general XC8 library
#define _XTAL_FREQ 48000000  // Brainbox Fun running at 48Mhz

#define POWEROUT_C2 PORTCbits.RC2    // using a define to give pin a better name
#define POWEROUT_E1 PORTEbits.RE1    // using a define to give pin a better name
#define POWEROUT_E0 PORTEbits.RE0    // using a define to give pin a better name
#define POWEROUT_C1 PORTCbits.RC1    // using a define to give pin a better name

    // The delay routine of the XC8 compiler is limited. 
    // __delay_ms(100); would be too large 
    // Solution: this function that repeats the 10msec delay 10 times
    void delay_10ms(unsigned char n) 
     { 
         while (n-- != 0) { 
             __delay_ms(10); 
         } 
     }

void main(void) // main program
{  
    TRISCbits.RC2 = 0; // make pin output pin
    TRISEbits.RE1 = 0; // make pin output pin
    TRISEbits.RE0 = 0; // make pin output pin
    TRISCbits.RC1 = 0; // make pin output pin
 
    while(1)
        { // never ending loop
        
            POWEROUT_C2 = 1; POWEROUT_E1 = 0; POWEROUT_E0 = 0; POWEROUT_C1 = 0;
            delay_10ms(100); // generates a 1sec delay
            POWEROUT_C2 = 0; POWEROUT_E1 = 1; POWEROUT_E0 = 0; POWEROUT_C1 = 0;
            delay_10ms(100); // generates a 1sec delay
            POWEROUT_C2 = 0; POWEROUT_E1 = 0; POWEROUT_E0 = 1; POWEROUT_C1 = 0;
            delay_10ms(100); // generates a 1sec delay
            POWEROUT_C2 = 0; POWEROUT_E1 = 0; POWEROUT_E0 = 0; POWEROUT_C1 = 1;
            delay_10ms(100); // generates a 1sec delay
        }
}
